RecordItem class
Constructors
-
RecordItem({required DateTime timestamp, required int sps, required Float32List l2Data, required Map<
String, List< allChannels})double> >
Properties
-
allChannels
→ Map<
String, List< double> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- l2Data → Float32List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sps → int
-
final
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited